@@ -43,9 +43,7 @@ PRIVATE mutex_t initialize_lock;
  * 2^x in increments of 8. */
 static uint32_t dtable_depth = 8;
 
-#ifndef NO_SAFE_CACHING
 _Atomic(uint64_t) objc_method_cache_version;
-#endif
 
 /**
  * Starting at `cls`, finds the class that provides the implementation of the
@@ -406,9 +404,7 @@ static BOOL installMethodInDtable(Class class,
 	// Invalidate the old slot, if there is one.
 	if (NULL != oldMethod)
 	{
-#ifndef NO_SAFE_CACHING
 		objc_method_cache_version++;
-#endif
 	}
 	return YES;
 }
@@ -524,9 +520,7 @@ PRIVATE void objc_update_dtable_for_new_superclass(Class cls, Class newSuper)
 	LOCK_RUNTIME_FOR_SCOPE();
 	rebaseDtableRecursive(cls, newSuper);
 	// Invalidate all caches after this operation.
-#ifndef NO_SAFE_CACHING
-		objc_method_cache_version++;
-#endif
+	objc_method_cache_version++;
 
 	return;
 }
